function [GauntCoeff] = GauntCoeff(L1,L2,L3,M1,M2,M3)
%Gaunt coefficients as per definition in Linton/Martin 2006
%which is consistent with the subset of coefficients 
%used by Artur Gower, 2018:
%A.L. Gower, M.J.A. Smith, W.J. Parnell, I.D. Abrahams, 
%Reflection from a multi-species material and its transmitted effective wavenumber, 
%Proc. R. Soc. A Math. Phys. Eng. Sci. 474 (2018) 20170864. 
%https://doi.org/10.1098/rspa.2017.0864.
%(Supplementary materials)
%and is my Eq 7 in the document "Notes on code for multiple species and
%Gaunt Wigner3j coefficients.docx"
%
%These relate to the function "GauntFull" (which is an alternative definition) as follows:
%G(n,p,q)=(1/(4*pi))*i^(n-q-p)*GauntFull(n,p,q,0,0,0)

GauntCoeff =(-1)^M3*...
    sqrt((2*L1+1)*(2*L2+1)*(2*L3+1)/(4*pi))*...
    w3j(L1,L2,L3,0,0,0)*w3j(L1,L2,L3,M1,M2,-M3);
end

