%--------------------------------------------------------------------------
function exclFunc=multiModeFac(n,K,Kq,ai,aj)
%These are the terms in the multiple scattering formula additional term 
%for multimode multiple scattering derived by Luppe (JASA 2012) 
%This version VP October 2014
%for general partial wave order (=l in paper)
%and for any combination of thermal or shear waves
%It calculates the square bracket of eqn 32a 
%kpb*jnp(kpb)*hn*kqb)-kqb*jn(kpb)*hnp(kqb)
%This is the function N in Luppe Conoir Valier Brasier 2022
%This is a modified polydisperse version by VP (v. approx)
%where b=ai+aj (sum of the two particle radii)
%and the factor is taken as the average using ai and aj as a
%ai and aj are the radius of the two particles (metres)
%Inputs:
%K, Kq: wavenumbers of mode p and mode q (e.g. compressional and thermal)
%ai,aj: radii of the two particles
%n: the partial wave order (=l in Luppe eqn 32a)
%outputs:
%the value of the function 
%kpb*jnp(kpb)*hn*kqb)-kqb*jn(kpb)*hnp(kqb)

b=ai+aj;%the exclusion zone radius
Kpb=K*b;
Kqb=Kq*b;
%calculate the required Bessel/Hankel functions
jnKpb=besselj(n+0.5,Kpb)/sqrt(Kpb); %without factor sqrt(pi/2)
hnKqb=besselh(n+0.5,1,Kqb)/sqrt(Kqb);%without factor sqrt(pi/2)
%derivatives from recurrence relations
if n==0
    jnpKpb=-besselj(1.5,Kpb)/sqrt(Kpb); %j0p=-j1 %without factor sqrt(pi/2)
    hnpKqb=-besselh(1.5,1,Kqb)/sqrt(Kqb); %h0p=-h1 %without factor sqrt(pi/2)
else
    jnpKpb=besselj(n-0.5,Kpb)/sqrt(Kpb)-(n+1)*jnKpb/Kpb; %jnp=jn_1-(n+1)*jn/x  %without factor sqrt(pi/2)
    hnpKqb=besselh(n-0.5,1,Kqb)/sqrt(Kqb)-(n+1)*hnKqb/Kqb; %hnp=hn_1-(n+1)*hn/x %without factor sqrt(pi/2)
end

%calculate the exclusion function, now inclding the factors of sqrt(pi/2)
%in each Bessel/Hankel function
exclFunc=(pi/2)*(Kpb*jnpKpb*hnKqb-Kqb*jnKpb*hnpKqb); %square bracket eqn 32a Luppe,Conoir,Norris 2012

